@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef KCHARTCHART_H
@@ -105,7 +105,7 @@ namespace KChart {
         KCHART_DECLARE_PRIVATE_BASE_POLYMORPHIC_QWIDGET( Chart )
 
     public:
-        explicit Chart ( QWidget* parent = 0 );
+        explicit Chart ( QWidget* parent = nullptr );
         ~Chart();
 
         /**
@@ -202,7 +202,7 @@ namespace KChart {
          * \sa addCoordinatePlane, takeCoordinatePlane
          */
         void replaceCoordinatePlane( AbstractCoordinatePlane* plane,
-                                     AbstractCoordinatePlane* oldPlane = 0 );
+                                     AbstractCoordinatePlane* oldPlane = nullptr );
 
         /**
          * Removes the coordinate plane from the chart, without deleting it.
@@ -261,7 +261,7 @@ namespace KChart {
          * \sa addHeaderFooter, takeHeaderFooter
          */
         void replaceHeaderFooter ( HeaderFooter* headerFooter,
-                                   HeaderFooter* oldHeaderFooter = 0 );
+                                   HeaderFooter* oldHeaderFooter = nullptr );
 
         /**
          * Removes the header (or footer, resp.) from the chart, without deleting it.
@@ -316,7 +316,7 @@ namespace KChart {
          *
          * \sa addLegend, takeLegend
          */
-        void replaceLegend ( Legend* legend, Legend* oldLegend = 0 );
+        void replaceLegend ( Legend* legend, Legend* oldLegend = nullptr );
 
         /**
          * Removes the legend from the chart, without deleting it.
@@ -451,7 +451,7 @@ namespace KChart {
         /**
           * Adjusts the internal layout when the chart is resized.
           */
-        /* reimp */ void resizeEvent ( QResizeEvent * event ) Q_DECL_OVERRIDE;
+        /* reimp */ void resizeEvent ( QResizeEvent * event ) override;
 
         /**
           * @brief Draws the background and frame, then calls paint().
@@ -460,18 +460,18 @@ namespace KChart {
           * class, but if you do, do not forget to call paint().
           * @sa paint
           */
-        /* reimp */ void paintEvent( QPaintEvent* event ) Q_DECL_OVERRIDE;
+        /* reimp */ void paintEvent( QPaintEvent* event ) override;
 
         /** reimp */
-        void mousePressEvent( QMouseEvent* event ) Q_DECL_OVERRIDE;
+        void mousePressEvent( QMouseEvent* event ) override;
         /** reimp */
-        void mouseDoubleClickEvent( QMouseEvent* event ) Q_DECL_OVERRIDE;
+        void mouseDoubleClickEvent( QMouseEvent* event ) override;
         /** reimp */
-        void mouseMoveEvent( QMouseEvent* event ) Q_DECL_OVERRIDE;
+        void mouseMoveEvent( QMouseEvent* event ) override;
         /** reimp */
-        void mouseReleaseEvent( QMouseEvent* event ) Q_DECL_OVERRIDE;
+        void mouseReleaseEvent( QMouseEvent* event ) override;
         /** reimp */
-        bool event( QEvent* event ) Q_DECL_OVERRIDE;
+        bool event( QEvent* event ) override;
 
     private:
         // TODO move this to the private class
