@@ -33,10 +33,11 @@
 #  define KCHART_DEPRECATED_NO_EXPORT KCHART_NO_EXPORT KCHART_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef KCHART_NO_DEPRECATED
 #    define KCHART_NO_DEPRECATED
 #  endif
 #endif
 
-#endif
+#endif /* KCHART_EXPORT_H */
